/* 

                          Firewall Builder

                 Copyright (C) 2000 NetCitadel, LLC

  Author:  Vadim Kurland     vadim@fwbuilder.org

  $Id: FWServiceReference.h 236 2008-12-25 20:36:41Z vadim $


  This program is free software which we release under the GNU General Public
  License. You may redistribute and/or modify this program under the terms
  of that license as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  To get a copy of the GNU General Public License, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/


#ifndef  __FWSRVREF_HH_FLAG__
#define  __FWSRVREF_HH_FLAG__

#include <fwbuilder/FWReference.h>

namespace libfwbuilder
{
    class Service;
    class ServiceGroup;

/**
 * This class represents object reference.
 */
class FWServiceReference : public FWReference
{
    public:

    DECLARE_FWOBJECT_SUBTYPE(FWServiceReference);

    FWServiceReference();
    FWServiceReference(const FWObjectDatabase *root,bool prepopulate);

    void setPointer(Service *o);
    void setPointer(ServiceGroup *o);

};

}

#endif
